==> haskell-statistics-0.14.0.2-9-i686.pkg.tar.xz: usr/share/haskell/register/haskell-statistics.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: statistics
version: 0.14.0.2
id: statistics-0.14.0.2-8IniBawHs1t3FhoawkiQzE
key: statistics-0.14.0.2-8IniBawHs1t3FhoawkiQzE
license: BSD2
copyright: 2009-2014 Bryan O'\''Sullivan
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: https://github.com/bos/statistics
synopsis: A library of statistical types, data, and functions
description:
    This library provides a number of common functions and types useful
    in statistics.  We focus on high performance, numerical robustness,
    and use of good algorithms.  Where possible, we provide
    references to the statistical literature.
    .
    The library'\''s facilities can be divided into four broad categories:
    .
    * Working with widely used discrete and continuous probability
    distributions.  (There are dozens of exotic distributions in use;
    we focus on the most common.)
    .
    * Computing with sample data: quantile estimation, kernel density
    estimation, histograms, bootstrap methods, significance testing,
    and regression and autocorrelation analysis.
    .
    * Random variate generation under several different distributions.
    .
    * Common statistical tests for significant differences between
    samples.
category: Math, Statistics
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
exposed-modules:
    Statistics.Autocorrelation Statistics.ConfidenceInt
    Statistics.Correlation Statistics.Correlation.Kendall
    Statistics.Distribution Statistics.Distribution.Beta
    Statistics.Distribution.Binomial
    Statistics.Distribution.CauchyLorentz
    Statistics.Distribution.ChiSquared
    Statistics.Distribution.DiscreteUniform
    Statistics.Distribution.Exponential
    Statistics.Distribution.FDistribution Statistics.Distribution.Gamma
    Statistics.Distribution.Geometric
    Statistics.Distribution.Hypergeometric
    Statistics.Distribution.Laplace Statistics.Distribution.Normal
    Statistics.Distribution.Poisson Statistics.Distribution.StudentT
    Statistics.Distribution.Transform Statistics.Distribution.Uniform
    Statistics.Function Statistics.Math.RootFinding Statistics.Matrix
    Statistics.Matrix.Algorithms Statistics.Matrix.Mutable
    Statistics.Matrix.Types Statistics.Quantile Statistics.Regression
    Statistics.Resampling Statistics.Resampling.Bootstrap
    Statistics.Sample Statistics.Sample.Histogram
    Statistics.Sample.KernelDensity
    Statistics.Sample.KernelDensity.Simple Statistics.Sample.Powers
    Statistics.Test.ChiSquared Statistics.Test.KolmogorovSmirnov
    Statistics.Test.KruskalWallis Statistics.Test.MannWhitneyU
    Statistics.Test.StudentT Statistics.Test.Types
    Statistics.Test.WilcoxonT Statistics.Transform Statistics.Types
hidden-modules: Statistics.Distribution.Poisson.Internal
                Statistics.Function.Comparison Statistics.Internal
                Statistics.Sample.Internal Statistics.Test.Internal
                Statistics.Types.Internal
abi: 519ba976873b7d7ea73985905d9c29c3
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/statistics-0.14.0.2
library-dirs: /usr/lib/ghc-8.0.2/site-local/statistics-0.14.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/statistics-0.14.0.2
hs-libraries: HSstatistics-0.14.0.2-8IniBawHs1t3FhoawkiQzE
depends:
    aeson-1.2.1.0-LtwtJj4trOg6E4DiroefXf base-4.9.1.0
    base-orphans-0.6-AbJ3lKVXygDCG0eeQEv8Iu binary-0.8.3.0
    deepseq-1.4.2.0 erf-2.0.0.0-IIRFGBpxAWtA7x6vFkIoaV
    math-functions-0.2.1.0-F0c8wUJFuGnIPpddl5zobd
    monad-par-0.3.4.8-6k4Aw33MS7Z5Fcws7vaHyh
    mwc-random-0.13.6.0-K5ePRTjCwYQ3u7Qp4sh2LR
    primitive-0.6.2.0-4578caNkWQ54Gt1mxLF2Yh
    vector-0.12.0.1-692PQMDMB6pIQ1uGwefDcQ
    vector-algorithms-0.7.0.1-CyLxDfJFRkcBZ53a4eh1Bl
    vector-binary-instances-0.2.3.5-Do2uVjLEGQcAMYmorIf1G3
    vector-th-unbox-0.2.1.6-46ifXx3IRXQF8ghjmDE5S
haddock-interfaces: /usr/share/doc/haskell-statistics/html/statistics.haddock
haddock-html: /usr/share/doc/haskell-statistics/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-statistics-0.14.0.2-10-i686.pkg.tar.xz: usr/share/haskell/register/haskell-statistics.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: statistics
version: 0.14.0.2
id: statistics-0.14.0.2-7TV97CNKf1b8jr8lMwH0AW
key: statistics-0.14.0.2-7TV97CNKf1b8jr8lMwH0AW
license: BSD2
copyright: 2009-2014 Bryan O'\''Sullivan
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: https://github.com/bos/statistics
synopsis: A library of statistical types, data, and functions
description:
    This library provides a number of common functions and types useful
    in statistics.  We focus on high performance, numerical robustness,
    and use of good algorithms.  Where possible, we provide
    references to the statistical literature.
    .
    The library'\''s facilities can be divided into four broad categories:
    .
    * Working with widely used discrete and continuous probability
    distributions.  (There are dozens of exotic distributions in use;
    we focus on the most common.)
    .
    * Computing with sample data: quantile estimation, kernel density
    estimation, histograms, bootstrap methods, significance testing,
    and regression and autocorrelation analysis.
    .
    * Random variate generation under several different distributions.
    .
    * Common statistical tests for significant differences between
    samples.
category: Math, Statistics
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
indefinite: False
exposed-modules:
    Statistics.Autocorrelation Statistics.ConfidenceInt
    Statistics.Correlation Statistics.Correlation.Kendall
    Statistics.Distribution Statistics.Distribution.Beta
    Statistics.Distribution.Binomial
    Statistics.Distribution.CauchyLorentz
    Statistics.Distribution.ChiSquared
    Statistics.Distribution.DiscreteUniform
    Statistics.Distribution.Exponential
    Statistics.Distribution.FDistribution Statistics.Distribution.Gamma
    Statistics.Distribution.Geometric
    Statistics.Distribution.Hypergeometric
    Statistics.Distribution.Laplace Statistics.Distribution.Normal
    Statistics.Distribution.Poisson Statistics.Distribution.StudentT
    Statistics.Distribution.Transform Statistics.Distribution.Uniform
    Statistics.Function Statistics.Math.RootFinding Statistics.Matrix
    Statistics.Matrix.Algorithms Statistics.Matrix.Mutable
    Statistics.Matrix.Types Statistics.Quantile Statistics.Regression
    Statistics.Resampling Statistics.Resampling.Bootstrap
    Statistics.Sample Statistics.Sample.Histogram
    Statistics.Sample.KernelDensity
    Statistics.Sample.KernelDensity.Simple Statistics.Sample.Powers
    Statistics.Test.ChiSquared Statistics.Test.KolmogorovSmirnov
    Statistics.Test.KruskalWallis Statistics.Test.MannWhitneyU
    Statistics.Test.StudentT Statistics.Test.Types
    Statistics.Test.WilcoxonT Statistics.Transform Statistics.Types
hidden-modules: Statistics.Distribution.Poisson.Internal
                Statistics.Function.Comparison Statistics.Internal
                Statistics.Sample.Internal Statistics.Test.Internal
                Statistics.Types.Internal
abi: 273b6bdeba1a0aee2924e474fbc530b9
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/statistics-0.14.0.2
library-dirs: /usr/lib/ghc-8.2.1/site-local/statistics-0.14.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/statistics-0.14.0.2
hs-libraries: HSstatistics-0.14.0.2-7TV97CNKf1b8jr8lMwH0AW
depends:
    aeson-1.2.1.0-JssfvwcKPt8HWgsY2AQth base-4.10.0.0
    base-orphans-0.6-9iPDLrUqQ5yHb9fb9OUZ9L binary-0.8.5.1
    deepseq-1.4.3.0 erf-2.0.0.0-5HxZcIsjrVYDzBhPSPHDu9
    math-functions-0.2.1.0-EZEKt9kx6qT9flHpNtHv8e
    monad-par-0.3.4.8-73MDniBlugD8L8eTzpiIpe
    mwc-random-0.13.6.0-9isDaETTkAQ4w6DSIRGQbB
    primitive-0.6.2.0-V0ibjLQDdN6fcQS5bjLVg
    vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi
    vector-algorithms-0.7.0.1-7iegdTORhweEiKzXWIWqK9
    vector-th-unbox-0.2.1.6-JdDbsOZxikU7Wr8hmBip1S
    vector-binary-instances-0.2.3.5-DWvVOI4GHrECD2ZJqrEThD
abi-depends: aeson-1.2.1.0-JssfvwcKPt8HWgsY2AQth=5a79246d87409b52d96906b6884ea8ba
             base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             base-orphans-0.6-9iPDLrUqQ5yHb9fb9OUZ9L=80bc3cbc1a27ff088178ac694da5ed41
             binary-0.8.5.1=b72be3099f9dcf7a652ee107dea27d54
             deepseq-1.4.3.0=ab64de23c9713e035549193002fe9df0
             erf-2.0.0.0-5HxZcIsjrVYDzBhPSPHDu9=7093557a54e0ef60dc422d9e6fdef74c
             math-functions-0.2.1.0-EZEKt9kx6qT9flHpNtHv8e=b7d492fe043fb847b390759ef14b7b32
             monad-par-0.3.4.8-73MDniBlugD8L8eTzpiIpe=42e4941a9d0f0e9e8b7cda8b3b7b2523
             mwc-random-0.13.6.0-9isDaETTkAQ4w6DSIRGQbB=2bc42ccbc5907c6a67bc15ff0ea72d9c
             primitive-0.6.2.0-V0ibjLQDdN6fcQS5bjLVg=9e7c576cd5d0cdeef0c68dbf576c880f
             vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi=bde86a27d0899b74a82f3bf1fe9b817c
             vector-algorithms-0.7.0.1-7iegdTORhweEiKzXWIWqK9=eaf868a69d5e56f04a2d5508f5079f9d
             vector-th-unbox-0.2.1.6-JdDbsOZxikU7Wr8hmBip1S=c9683165a44508688f064b06cffda0d8
             vector-binary-instances-0.2.3.5-DWvVOI4GHrECD2ZJqrEThD=23f06a84a106196e9d65f622e61b1fe6
haddock-interfaces: /usr/share/doc/haskell-statistics/html/statistics.haddock
haddock-html: /usr/share/doc/haskell-statistics/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
